init_with_android_context

Function init_with_android_context 

pub fn init_with_android_context()
Register the host’s JavaVM / Context pointers with ndk-context so the Android I/O layer can resolve them. Hosts pass the pointers the Android runtime hands to android_main, so they are not required to be unsafe.